@@ -20,6 +20,7 @@ mixed_VA <- c(32, "20/40",3, NA, "1.1", 0.2, -0.3, "NA", "eye", -0.4, "NLP", "PL
 mixed_VA1 <- c(32, "20/40",3, NA, "1.1", 0.2, -0.3, "NA",  -0.4, "NLP", "PL")
 mixed_VA2 <- c(32, "20/40",3, NA, "1.1", 0.2, -0.3, "NA",   "NLP", "PL")
 etdrs_logmar <- 0:1
+etdrs_logmar2 <-  c(0.2, 0.1, 75)
 etdrs_logmar_na <- c(0:1, NA)
 snellen_logmar <- intersect(as.numeric(va_chart$snellendec), va_chart$logmar)
 snellen_logmar_na <- c(snellen_logmar, NA)
@@ -101,33 +102,18 @@ test_that("message", {
   expect_message(va(snellendec, from = "snellendec", to = "logmar"), regexp = NA)
   expect_message(va(quali_snellen_ft, to = "logmar"), "From snellen")
   expect_message(va(logmar, to = "etdrs"), "From logmar")
-  expect_message(va(etdrs_logmar, to = "logmar"), "From logmar")
-  expect_message(va(etdrs_logmar_na, to = "logmar"), "From logmar")
+  expect_message(va(etdrs_logmar, to = "logmar"), "From etdrs. Could be")
+  expect_message(va(etdrs_logmar_na, to = "logmar"), "From etdrs. Could be")
   expect_message(va(snellen_logmar, to = "etdrs"), "From logmar")
   expect_message(va(snellen_logmar_na, to = "etdrs"), "From logmar")
   expect_message(va(snellen_unplaus), "20x NA introduced for")
   expect_message(va(etdrs_unplaus, to = "logmar"), "1x NA introduced for: -1")
-  expect_message(va(etdrs_unplaus, to = "logmar"), "From etdrs")
   expect_message(va(logmar_unplaus, to = "logmar"), "From logmar")
   expect_message(va(logmar_unplaus, to = "logmar"), "41x NA introduced for")
 })
 
 
 test_that("return", {
-  expect_identical(eye:::which_va(etdrs), c("etdrs", "logmar", "snellendec"))
-  expect_identical(eye:::which_va(etdrs_unplaus), c("etdrs", "logmar", "snellendec"))
-  expect_identical(eye:::which_va(snellendec), c("logmar","snellendec"))
-  expect_identical(eye:::which_va(snellenm), "snellen")
-  expect_identical(eye:::which_va(snellenft), "snellen")
-  expect_identical(eye:::which_va(logmar), c("logmar", "snellendec"))
-  expect_identical(eye:::which_va(logmar_unplaus), c("logmar", "snellendec"))
-  expect_identical(eye:::which_va(clean_va(quali)), "quali")
-  expect_identical(eye:::which_va(snellen_unplaus), "failed")
-  expect_identical(eye:::which_va(clean_va(quali_logmar)), c("logmar", "snellendec"))
-  expect_identical(eye:::which_va(clean_va(quali_snellen_ft)), "snellen")
-  expect_identical(eye:::which_va(clean_va(quali_snellen_m)), "snellen")
-  expect_identical(eye:::which_va(etdrs_logmar), c("logmar", "snellendec", "etdrs"))
-  expect_identical(eye:::which_va(snellen_logmar), c("logmar","snellendec"))
   expect_true(inherits(va(va_vec2, to = "etdrs"), "etdrs"))
   expect_length(va(va_vec), length(va_vec))
   expect_length(va(va_vec1), length(va_vec1))
